import click
import jwt
from packages.j import decode_jwt_without_verify


@click.command()
@click.argument('s', nargs=-1)
def hello(s):
    raw = ''
    for i, value in enumerate(s):
        if i != 0:
            raw += '-' + value.lower()
        else:
            raw += value.lower()
    click.echo(raw)


@click.command()
@click.argument("token", nargs=1)
def jwt_tool(token):
    try:
        decode_token = decode_jwt_without_verify(token)
    except jwt.PyJWTError:
        click.echo("sorry your token is invalid")
    else:
        click.echo(decode_token)



from setuptools import setup, find_packages


def long_long_description():
    with open('README.md', 'r') as f:
        desc = f.read()
    return desc


setup(
    name='simple-gen',
    version='2020.01.08',
    description='gen files',
    author='buglan',
    author_email='1831353087@qq.com',
    packages=find_packages(),
    install_requires=['click', 'PyJWT'],
    entry_points='''
        [console_scripts]
        hello = packages.gen:hello
        s = packages.group:hello
        jwt = packages.group:jwt_tool
    ''',
    setup_requires=[
        'pytest-runner'
    ],
    tests_require=[
        'pytest',
    ]

)
